@@ -34,7 +34,9 @@ from openfermion.chem import (
     make_reduced_hamiltonian,
 )
 
-from openfermion.functionals import contextuality
+from openfermion.functionals import (contextuality, get_one_norm_mol,
+                                     get_one_norm_mol_woconst, get_one_norm_int,
+                                     get_one_norm_int_woconst)
 
 from openfermion.hamiltonians import (
     FermiHubbardModel,
