@@ -871,30 +871,9 @@ class MolecularData(object):
 
         # Get integrals.
         one_body_integrals, two_body_integrals = self.get_integrals()
-
-        # Determine core constant
-        core_constant = 0.0
-        for i in occupied_indices:
-            core_constant += 2 * one_body_integrals[i, i]
-            for j in occupied_indices:
-                core_constant += (2 * two_body_integrals[i, j, j, i] -
-                                  two_body_integrals[i, j, i, j])
-
-        # Modified one electron integrals
-        one_body_integrals_new = numpy.copy(one_body_integrals)
-        for u in active_indices:
-            for v in active_indices:
-                for i in occupied_indices:
-                    one_body_integrals_new[u, v] += (
-                        2 * two_body_integrals[i, u, v, i] -
-                        two_body_integrals[i, u, i, v])
-
-        # Restrict integral ranges and change M appropriately
-        return (core_constant,
-                one_body_integrals_new[numpy.ix_(active_indices,
-                                                 active_indices)],
-                two_body_integrals[numpy.ix_(active_indices, active_indices,
-                                             active_indices, active_indices)])
+        return reps.get_active_space_integrals(one_body_integrals,
+                                               two_body_integrals,
+                                               occupied_indices, active_indices)
 
     def get_molecular_hamiltonian(self,
                                   occupied_indices=None,
@@ -953,17 +932,15 @@ class MolecularData(object):
                 raise MissingCalculationError(
                     'Missing FCI RDM in {}'.format(self.filename) +
                     'Run FCI calculation before loading FCI RDMs.')
-            else:
-                one_rdm = self.fci_one_rdm
-                two_rdm = self.fci_two_rdm
+            one_rdm = self.fci_one_rdm
+            two_rdm = self.fci_two_rdm
         else:
             if self.cisd_energy is None:
                 raise MissingCalculationError(
                     'Missing CISD RDM in {}'.format(self.filename) +
                     'Run CISD calculation before loading CISD RDMs.')
-            else:
-                one_rdm = self.cisd_one_rdm
-                two_rdm = self.cisd_two_rdm
+            one_rdm = self.cisd_one_rdm
+            two_rdm = self.cisd_two_rdm
 
         # Truncate.
         one_rdm[numpy.absolute(one_rdm) < EQ_TOLERANCE] = 0.
