@@ -49,8 +49,8 @@ def general_basis_change(general_tensor, rotation_matrix, key):
             n_qubits by n_qubits. Assumed to be unitary.
         key: A tuple indicating the type of general_tensor. Assumed to be
             non-empty. For example, a tensor storing coefficients of
-            :math:`a^\dagger_p a_q` would have a key of (1, 0) whereas a tensor
-            storing coefficients of :math:`a^\dagger_p a_q a_r a^\dagger_s`
+            $a^\dagger_p a_q$ would have a key of (1, 0) whereas a tensor
+            storing coefficients of $a^\dagger_p a_q a_r a^\dagger_s$
             would have a key of (1, 0, 0, 1).
 
     Returns:
